/*
 * Java
 *
 * Copyright 2015-2022 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.kf;

import java.io.IOException;
import java.io.InputStream;

import ej.kf.AlreadyLoadedFeatureException;
import ej.kf.Feature;
import ej.kf.IncompatibleFeatureException;
import ej.kf.InvalidFormatException;
import ej.kf.Kernel;

/**
 * Default loader that does nothing for statically installed features
 * (these features cannot be loaded dynamically, and cannot be unloaded).
 */
public class InstalledFeatureLoader implements IFeatureLoader {

	@Override
	public boolean canLoad(byte[] signature) {
		return false;
	}

	@Override
	public boolean canUnload() {
		return false;
	}

	@Override
	public Feature load(byte[] signature,
			InputStream is) throws IOException, InvalidFormatException,
	IncompatibleFeatureException, AlreadyLoadedFeatureException {
		throw new AssertionError();
	}

	@Override
	public boolean unload(Feature f) {
		return false;
	}

	@Override
	public void loadInstalledFeatures() {
		// instantiate installed Features (post-link firmware)
		int nbInstalledFeatures = KernelNatives.getMaxNbInstalledFeatures();
		InstalledFeatureLoader loader = new InstalledFeatureLoader();
		for (int i = -1; ++i < nbInstalledFeatures;) {
			long featureSectionDescriptor = KernelNatives.getInstalledFeatureDescriptor(i);
			if (featureSectionDescriptor != -1) {
				Feature f = new Feature(loader, featureSectionDescriptor, Feature.FEATURE_CUSTOM_HANDLE_NONE);
				Kernel.addInstalledFeature(f);
			}
		}
	}
}
