/*
 * Java
 *
 * Copyright 2019-2022 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.util;

/**
 * Not in API.
 */
public class DeviceNatives {

	private DeviceNatives() {
		// private constructor
	}

	/**
	 * Fills the given buffer with the name of the architecture as a null-terminated
	 * string.
	 *
	 * @param buffer       the buffer to fill with the name of the architecture.
	 * @param bufferLength the size of the buffer.
	 * @return true on success or false on error.
	 */
	public static native boolean getArchitecture(byte[] buffer, int bufferLength);

	/**
	 * Fills the given buffer with the ID of the device.
	 *
	 * @param buffer
	 *            the buffer to fill with the ID.
	 * @param bufferLength
	 *            the size of the buffer.
	 * @return the number of bytes filled or 0 on error.
	 */
	public static native int getId(byte[] buffer, int bufferLength);

	/**
	 * Fills the given buffer with the Version of the device as a null-terminated
	 * string.
	 *
	 * @param buffer       the buffer to fill with the Version.
	 */
	public static native void getVersion(byte[] buffer);

	/**
	 * Reboots the device.
	 */
	public static native void reboot();

	/**
	 * Shutdowns the device.
	 */
	public static native void shutdown();

}
